@@ -8,7 +8,7 @@ from quartic_sdk.utilities.constants import OAUTH, BASIC
 
 class Configuration:
 
-    def __init__(self, host, username=None, password=None, oauth_token=None, cert_path=None, verify_ssl=True):
+    def __init__(self, host, username=None, password=None, oauth_token=None, cert_path=None, verify_ssl=True, gql_host=None):
         """
         Initialize the configuration
         :param host:
@@ -16,6 +16,7 @@ class Configuration:
         :param password:
         :param oauth_token:
         :param verify_ssl:
+        :param graphql server url
         """
         self.host = host
         if oauth_token:
@@ -31,6 +32,7 @@ class Configuration:
 
         self.verify_ssl = verify_ssl
         self.cert_path = cert_path
+        self.gql_host = gql_host or self.host
 
     def get_basic_auth_token(self):
         """
@@ -43,7 +45,7 @@ class Configuration:
         ).get('authorization')
 
     @classmethod
-    def get_configuration(cls, host, username=None, password=None, oauth_token=None, cert_path=None, verify_ssl=True):
+    def get_configuration(cls, host, username=None, password=None, oauth_token=None, cert_path=None, verify_ssl=True, gql_host=None):
         """
         The method gets all the required params and returns the configuration details
         for making the API calls
@@ -53,6 +55,7 @@ class Configuration:
         :param oauth_token: oauth token for authenticating requests
         :param cert_path: path of certificate
         :param verify_ssl: boolean value
+        :param gql_host: graphql server url
         :return: Configuration object
         """
-        return Configuration(host, username, password, oauth_token, cert_path, verify_ssl)
+        return Configuration(host, username, password, oauth_token, cert_path, verify_ssl, gql_host)
